@@ -5,19 +5,21 @@ from typing import Literal
 from aliyun.log import GetLogsRequest, LogItem, PutLogsRequest
 from aliyun.log import LogClient as SlsLogClient
 from aliyun.log.auth import AUTH_VERSION_4
-from ..utils.env import check_env
 
 
 
 class AliCloudSls:
-
-    def __init__(self, access_key_id: str=None, access_key_secret: str=None, project: str, logstore: str):
+    '''
+    pip install -U aliyun-log-python-sdk
+    '''
+    def __init__(self, access_key_id: str=None, access_key_secret: str=None, project: str=None, logstore: str=None, env: str='prod'):
         # 日志服务的服务接入点
         self.endpoint = "cn-shanghai.log.aliyuncs.com"
         # 创建 LogClient 实例，使用 V4 签名，根据实际情况填写 region，这里以杭州为例
         self.client = SlsLogClient(self.endpoint, access_key_id, access_key_secret, auth_version=AUTH_VERSION_4, region='cn-shanghai')
         self.project = project
         self.logstore = logstore
+        self.env = env
 
     def get_logs(self, project_name, logstore_name, query, from_time, to_time): 
         logstore_index = {'line': {
@@ -57,7 +59,7 @@ class AliCloudSls:
         log_group = []
         log_item = LogItem()
         contents = [
-            ('env', check_env()),
+            ('env', self.env),
             ('level', level),
             ('app', app),
             ('msg', msg),
@@ -69,8 +71,9 @@ class AliCloudSls:
         log_item.set_contents(contents)
         log_group.append(log_item)
         request = PutLogsRequest(self.project, self.logstore, topic, "", log_group, compress=False)
-        self.client.put_logs(request)
-    
+        r = self.client.put_logs(request)
+        return r
+        
     def put_logs_for_meraki(self, alert):
         log_group = []
         log_item = LogItem()
