@@ -168,41 +168,41 @@ class VictoriaMetrics:
             ReturnResponse: 
                 code = 0 正常, code = 1 异常, code = 2 没有查询到数据, 建议将其判断为正常
         '''
-        if target:
-            # 这里需要在字符串中保留 {}，同时插入 target，可以用双大括号转义
-            query = f"ping_result_code{{target='{target}'}}"
-        else:
-            query = "ping_result_code"
-        
-        if last_minute:
-            query = query + f"[{last_minute}m]"
-        
-        if env == 'dev':
+        query = f'avg_over_time((ping_result_code{{target="{target}"}})[{last_minute}m])'
+        if self.env == 'dev':
             r = load_dev_file(dev_file)
         else:
             r = self.query(query=query)
- 
         if r.code == 0:
-            values = r.data[0]['values']
-            if len(values) == 2 and values[1] == "0":
-                code = 0
-                msg = f"已检查 {target} 最近 {last_minute} 分钟是正常的!"
+            value = r.data[0]['value'][1]
+            if value == '0':
+                return ReturnResponse(code=0, msg=f"已检查 {target} 最近 {last_minute} 分钟是正常的!", data=r.data)
             else:
-                if all(str(item[1]) == "1" for item in values):
-                    code = 1
-                    msg = f"已检查 {target} 最近 {last_minute} 分钟是异常的!"
-                else:
-                    code = 0
-                    msg = f"已检查 {target} 最近 {last_minute} 分钟是正常的!"
-        elif r.code == 2:
-            code = 2
-            msg = f"没有查询到 {target} 最近 {last_minute} 分钟的ping结果!"
-        try:
-            data = r.data[0]
-        except KeyError:
-            data = r.data
+                return ReturnResponse(code=1, msg=f"已检查 {target} 最近 {last_minute} 分钟是异常的!", data=r.data)
+        else:
+            return r
+
+    def check_unreachable_ping_result(self, dev_file: str='') -> ReturnResponse:
+        '''
+        检查ping结果
+
+        Args:
+            target (str): 目标地址
+            last_minute (int, optional): 最近多少分钟. Defaults to 10.
+            env (str, optional): 环境. Defaults to 'prod'.
+            dev_file (str, optional): 开发文件. Defaults to ''.
+
+        Returns:
+            ReturnResponse: 
+                code = 0 正常, code = 1 异常, code = 2 没有查询到数据, 建议将其判断为正常
+        '''
+        query = "ping_result_code == 1"
         
-        return ReturnResponse(code=code, msg=msg, data=data)
+        if self.env == 'dev':
+            r = load_dev_file(dev_file)
+        else:
+            r = self.query(query=query)
+        return r
 
     def check_interface_rate(self,
                              direction: Literal['in', 'out'],
@@ -251,16 +251,47 @@ class VictoriaMetrics:
             ReturnResponse: _description_
         '''
         if direction == 'in':
-            query = f'avg_over_time(rate(snmp_interface_ifHCInOctets{{sysName="{sysname}", ifName="{ifname}"}}[{last_minutes}m]) * 8 [{last_hours}h:]) / 1e6'
+            query = f'avg_over_time((rate(snmp_interface_ifHCInOctets{{sysName="{sysname}", ifName="{ifname}"}}[{last_minutes}m]) * 8) [{last_hours}h:]) / 1e6'
         else:
-            query = f'avg_over_time(rate(snmp_interface_ifHCOutOctets{{sysName="{sysname}", ifName="{ifname}"}}[{last_minutes}m]) * 8 [{last_hours}h:]) / 1e6'
+            query = f'avg_over_time((rate(snmp_interface_ifHCOutOctets{{sysName="{sysname}", ifName="{ifname}"}}[{last_minutes}m]) * 8) [{last_hours}h:]) / 1e6'
         r = self.query(query)
         try:
             rate = r.data[0]['value'][1]
             return ReturnResponse(code=0, msg=f"查询 {sysname} {ifname} 最近 {last_hours} 小时平均速率为 {round(float(rate), 2)} Mbit/s", data=round(float(rate), 2))
         except KeyError:
             return ReturnResponse(code=1, msg=f"查询 {sysname} {ifname} 最近 {last_hours} 小时平均速率为 0 Mbit/s")
-    
+
+    def check_interface_max_rate(self,
+                                 direction: Literal['in', 'out'],
+                                 sysname: str, 
+                                 ifname:str, 
+                                 last_hours: Optional[int] = 24,
+                                 last_minutes: Optional[int] = 5,
+                                ) -> ReturnResponse:
+        '''
+        _summary_
+
+        Args:
+            direction (Literal[&#39;in&#39;, &#39;out&#39;]): _description_
+            sysname (str): _description_
+            ifname (str): _description_
+            last_hours (Optional[int], optional): _description_. Defaults to 24.
+            last_minutes (Optional[int], optional): _description_. Defaults to 5.
+
+        Returns:
+            ReturnResponse: _description_
+        '''
+        if direction == 'in':
+            query = f'max_over_time((rate(snmp_interface_ifHCInOctets{{sysName="{sysname}", ifName="{ifname}"}}[{last_minutes}m]) * 8) [{last_hours}h:]) / 1e6'
+        else:
+            query = f'max_over_time((rate(snmp_interface_ifHCOutOctets{{sysName="{sysname}", ifName="{ifname}"}}[{last_minutes}m]) * 8) [{last_hours}h:]) / 1e6'
+        r = self.query(query)
+        try:
+            rate = r.data[0]['value'][1]
+            return ReturnResponse(code=0, msg=f"查询 {sysname} {ifname} 最近 {last_hours} 小时最大速率为 {round(float(rate), 2)} Mbit/s", data=round(float(rate), 2))
+        except KeyError:
+            return ReturnResponse(code=1, msg=f"查询 {sysname} {ifname} 最近 {last_hours} 小时最大速率为 0 Mbit/s")
+
     def check_snmp_port_status(self, sysname: str=None, if_name: str=None, last_minute: int=5, dev_file: str=None) -> ReturnResponse:
         '''
         查询端口状态
@@ -343,4 +374,30 @@ class VictoriaMetrics:
             labels['schedule_type'] = 'cron'
             labels['schedule_cron'] = schedule_cron
         r = self.insert(metric_name="cronjob_run_duration_seconds", labels=labels, value=duration_seconds)
-        return r
\ No newline at end of file
+        return r
+    
+    def get_vmware_esxhostnames(self, vcenter: str=None) -> list:
+        '''
+        _summary_
+        '''
+        esxhostnames = []
+        query = f'vsphere_host_sys_uptime_latest{{vcenter="{vcenter}"}}'
+        metrics = self.query(query=query).data
+        for metric in metrics:
+            esxhostname = metric['metric']['esxhostname']
+            esxhostnames.append(esxhostname)
+        return esxhostnames
+    
+    def get_vmware_cpu_usage(self, vcenter: str=None, esxhostname: str=None) -> float:
+        '''
+        _summary_
+        '''
+        query = f'vsphere_host_cpu_usage_average{{vcenter="{vcenter}", esxhostname="{esxhostname}"}}'
+        return self.query(query=query).data[0]['value'][1]
+    
+    def get_vmware_memory_usage(self, vcenter: str=None, esxhostname: str=None) -> float:
+        '''
+        _summary_
+        '''
+        query = f'vsphere_host_mem_usage_average{{vcenter="{vcenter}", esxhostname="{esxhostname}"}}'
+        return self.query(query=query).data[0]['value'][1]
\ No newline at end of file
